#!/usr/bin/env node
'use strict';

// NOTE: To allow `pidof motion`
process.title = 'motion';

process.on('uncaughtException', function (error) {
  console.log('Uncaught Exception', error && error.stack || error);
});
process.on('unhandledRejection', function (reason, promise) {
  console.log('Unhandled Rejection at: Promise ', promise, ' reason: ', reason);
});

var Path = require('path');
var Motion = require('../');
var chalk = require('chalk');
var trim = require('cool-trim');
var manifest = require('../../package.json');
var parameters = process.argv.slice(2);
var command = parameters[0];
var options = require('minimist')(parameters);
var commands = options._;
var showHelp = options.h || options.help;

if (options.v || options.version) {
  console.log('Motion v' + manifest.version);
  process.exit();
}

function getMotion() {
  var rootDirectory = arguments.length <= 0 || arguments[0] === undefined ? process.cwd() : arguments[0];

  return Motion.create({ rootDirectory: rootDirectory }).then(function (motion) {
    motion.onDidError(function (error) {
      motion.cli.log(error);
    });
    return motion;
  });
}
function handleError(error) {
  console.error(error && error.stack || error);
  process.exit(1);
}

if (command === 'new') {
  (function () {
    var name = commands[1];
    if (!name) {
      console.error('Please enter a valid app name');
      process.exit(1);
    }
    getMotion(Path.join(process.cwd(), name)).then(function (motion) {
      return motion.init();
    }).then(function () {
      console.log(trim('\n      ' + chalk.green('App created successfully! Enjoy') + '\n      ' + chalk.yellow('To run motion in your new app, do') + '\n        $ cd ' + name + '\n        $ motion\n    '));
    }, handleError);
  })();
} else if (command === 'build') {
  getMotion().then(function (motion) {
    return motion.build(process.stdout.isTTY);
  }).then(function () {
    console.log(trim('\n      ' + chalk.green('App built successfully') + '\n      To access the built files, do\n        $ cd .motion/\n    '));
  }, handleError);
} else if (command === 'init') {
  getMotion().then(function (motion) {
    return motion.init();
  }).then(function () {
    console.log(trim('\n      ' + chalk.green('Motion initialized successfully! Enjoy') + '\n      ' + chalk.yellow('To run motion in your new app, do') + '\n        $ motion\n    '));
  }, handleError);
} else if (!commands.length && !showHelp) {
  // run
  getMotion().then(function (motion) {
    return motion.watch(process.stdout.isTTY);
  }).catch(handleError);
} else {
  showHelp = true;
}

if (showHelp) {
  console.log(trim('\n    Motion v' + manifest.version + ', Usage:\n      motion                        Run current Motion app\n      motion -h, --help             Show this help\n      motion -v, --version          Show Motion version\n      motion new $name              Create new Motion app with $name as name\n      motion build                  Built current Motion app\n      motion init                   Add Motion config to current app\n    '));
  process.exit(1);
}
//# sourceMappingURL=index.js.map