'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getPundleInstance = exports.TICK = exports.X = undefined;

var getPundleInstance = exports.getPundleInstance = function () {
  var ref = _asyncToGenerator(function* (state, config, cli, terminal, development, errorCallback) {
    var pundleConfig = {
      hmr: development,
      entry: [require.resolve('babel-regenerator-runtime'), config.rootDirectory],
      rootDirectory: config.rootDirectory,
      resolve: {
        root: config.rootDirectory
      },
      replaceVariables: {
        'process.env.NODE_ENV': '"' + (development ? 'development' : 'production') + '"'
      }
    };

    var userPlugins = (state.config.babel && state.config.babel.plugins || []).map(function (plugin) {
      return plugin.substr(0, 1) === '.' ? _path2.default.join(config.rootDirectory, plugin) : _path2.default.join(config.rootDirectory, 'node_modules', plugin);
    });

    var plugins = [[require.resolve('pundle-npm-installer'), {
      save: state.get().npm_save,
      rootDirectory: config.rootDirectory,
      onBeforeInstall: function onBeforeInstall(id, name) {
        if (terminal) {
          var message = 'Installing ' + name;
          cli.addSpinner(message);
        }
      },
      onAfterInstall: function onAfterInstall(id, name, error) {
        if (terminal) {
          var message = 'Installing ' + name;
          cli.removeSpinner(message);
          if (error) {
            cli.log('Install ' + name + ' ' + X);
            cli.log(error);
          } else {
            cli.log('Install ' + name + ' ' + TICK);
          }
        } else if (error) {
          errorCallback(error);
        }
      }
    }], [require.resolve('babel-pundle'), {
      config: {
        presets: [require.resolve('babel-preset-motion')],
        plugins: userPlugins
      },
      ignored: /(node_modules|bower_components|\.motion)/
    }]];

    if (!development) {
      var _pundle = new _pundle3.default(pundleConfig);
      yield _pundle.loadPlugins(plugins);
      return _pundle;
    }
    var pundle = new _pundleDev2.default({
      pundle: pundleConfig,
      watcher: {
        onError: function onError(error) {
          errorCallback(error);
        }
      },
      middleware: {
        sourceMap: true,
        sourceRoot: config.dataDirectory,
        publicPath: '/',
        publicBundlePath: '/_/bundle.js'
      },
      server: {
        port: state.get().web_server_port
      }
    });
    yield pundle.pundle.loadPlugins(plugins);
    pundle.server.use('*', function serveRequest(req, res, next) {
      var error = arguments.length <= 3 || arguments[3] === undefined ? false : arguments[3];

      // Ignore both bundle and it's map
      if (req.baseUrl.indexOf('/_/bundle.js') === 0) {
        next();
        return;
      }
      (0, _send2.default)(req, req.baseUrl, { root: config.dataDirectory, index: 'index.html' }).on('error', function () {
        if (error) {
          next();
        } else {
          req.baseUrl = '/index.html';
          serveRequest(req, res, next, true);
        }
      }).on('directory', function () {
        next();
      }).pipe(res);
    });
    pundle.pundle.observeCompilations(function (compilation) {
      compilation.onDidCompile(function (_ref) {
        var filePath = _ref.filePath;

        if (filePath.substr(0, 5) === '$root') {
          cli.log(_chalk2.default.dim(filePath) + ' ' + _chalk2.default.green('✓'));
        }
      });
    });
    return pundle;
  });

  return function getPundleInstance(_x, _x2, _x3, _x4, _x5, _x6) {
    return ref.apply(this, arguments);
  };
}();

exports.fillConfig = fillConfig;
exports.getLocalModulePath = getLocalModulePath;
exports.getRandomNumber = getRandomNumber;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _pundle2 = require('pundle');

var _pundle3 = _interopRequireDefault(_pundle2);

var _pundleDev = require('pundle-dev');

var _pundleDev2 = _interopRequireDefault(_pundleDev);

var _send = require('send');

var _send2 = _interopRequireDefault(_send);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _config = require('./config');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { return step("next", value); }, function (err) { return step("throw", err); }); } } return step("next"); }); }; }

var X = exports.X = '✗';
var TICK = exports.TICK = '✓';

function fillConfig(config) {
  if (typeof config.dataDirectory !== 'string') {
    config.dataDirectory = _path2.default.join(config.rootDirectory, _config.DIRECTORY_NAME);
  }
}

function getLocalModulePath(name) {
  return _path2.default.dirname(require.resolve(name + '/package.json'));
}

// From: goo.gl/fZA6BF
function getRandomNumber(min, max) {
  return Math.floor(Math.random() * (max - min)) + min;
}
//# sourceMappingURL=helpers.js.map