'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _assert = require('assert');

var _assert2 = _interopRequireDefault(_assert);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('./fs');

var _sbEventKit = require('sb-event-kit');

var _state = require('./state');

var _state2 = _interopRequireDefault(_state);

var _cli = require('./cli');

var _cli2 = _interopRequireDefault(_cli);

var _error = require('./error');

var _helpers = require('./helpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { return step("next", value); }, function (err) { return step("throw", err); }); } } return step("next"); }); }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var Motion = function () {
  function Motion(state, config) {
    var _this = this;

    _classCallCheck(this, Motion);

    (0, _assert2.default)(state instanceof _state2.default && (typeof config === 'undefined' ? 'undefined' : _typeof(config)) === 'object', 'Use Motion.create instead of constructor');

    this.cli = new _cli2.default(state, config);
    this.state = state;
    this.config = config;
    this.emitter = new _sbEventKit.Emitter();
    this.watching = false;
    this.subscriptions = new _sbEventKit.CompositeDisposable();

    this.subscriptions.add(this.emitter);
    this.subscriptions.add(this.cli);
    this.cli.onShouldBuild(_asyncToGenerator(function* () {
      yield _this.build(false);
    }));
    this.cli.onShouldDispose(function () {
      _this.dispose();
    });
  }

  _createClass(Motion, [{
    key: 'exists',
    value: function () {
      var ref = _asyncToGenerator(function* () {
        return yield (0, _fs.exists)(this.config.dataDirectory);
      });

      function exists() {
        return ref.apply(this, arguments);
      }

      return exists;
    }()
  }, {
    key: 'watch',
    value: function () {
      var ref = _asyncToGenerator(function* () {
        var _this2 = this;

        var terminal = arguments.length <= 0 || arguments[0] === undefined ? false : arguments[0];

        if (!(yield this.exists())) {
          throw new _error.MotionError(_error.ERROR_CODE.NOT_MOTION_APP);
        }

        this.state.get().running = true;
        this.state.get().process_id = process.pid;
        yield this.state.write();

        if (terminal) {
          this.cli.activate();
        }
        var pundle = yield (0, _helpers.getPundleInstance)(this.state, this.config, this.cli, terminal, true, function (error) {
          _this2.emitter.emit('did-error', error);
        });
        pundle.listen(this.state.get().web_server_port);
        var reloadHook = this.cli.onShouldReload(_asyncToGenerator(function* () {
          var _iteratorNormalCompletion = true;
          var _didIteratorError = false;
          var _iteratorError = undefined;

          try {
            for (var _iterator = pundle.pundle.compilations[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
              var entry = _step.value;

              entry.clearCache();
              yield entry.compile();
            }
          } catch (err) {
            _didIteratorError = true;
            _iteratorError = err;
          } finally {
            try {
              if (!_iteratorNormalCompletion && _iterator.return) {
                _iterator.return();
              }
            } finally {
              if (_didIteratorError) {
                throw _iteratorError;
              }
            }
          }
        }));
        var disposable = new _sbEventKit.Disposable(function () {
          _this2.state.get().running = false;
          _this2.state.write();
          _this2.subscriptions.remove(disposable);
          pundle.dispose();
          reloadHook.dispose();
        });
        if (terminal) {
          this.cli.log('Creating compile cache');
          var _iteratorNormalCompletion2 = true;
          var _didIteratorError2 = false;
          var _iteratorError2 = undefined;

          try {
            for (var _iterator2 = pundle.pundle.compilations[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
              var entry = _step2.value;

              yield entry.compile();
            }
          } catch (err) {
            _didIteratorError2 = true;
            _iteratorError2 = err;
          } finally {
            try {
              if (!_iteratorNormalCompletion2 && _iterator2.return) {
                _iterator2.return();
              }
            } finally {
              if (_didIteratorError2) {
                throw _iteratorError2;
              }
            }
          }
        }

        this.subscriptions.add(disposable);
        return disposable;
      });

      function watch(_x) {
        return ref.apply(this, arguments);
      }

      return watch;
    }()
  }, {
    key: 'build',
    value: function () {
      var ref = _asyncToGenerator(function* () {
        var _this3 = this;

        var terminal = arguments.length <= 0 || arguments[0] === undefined ? false : arguments[0];

        if (!(yield this.exists())) {
          throw new _error.MotionError(_error.ERROR_CODE.NOT_MOTION_APP);
        }
        var compilation = yield (0, _helpers.getPundleInstance)(this.state, this.config, this.cli, terminal, false, function (error) {
          _this3.emitter.emit('did-error', error);
        });
        yield (0, _fs.mkdir)(_path2.default.join(this.config.dataDirectory, '_'));
        yield (0, _fs.writeFile)(_path2.default.join(this.config.dataDirectory, '_/bundle.js'), (yield compilation.compile()));
      });

      function build(_x3) {
        return ref.apply(this, arguments);
      }

      return build;
    }()
  }, {
    key: 'init',
    value: function () {
      var ref = _asyncToGenerator(function* () {
        if (yield this.exists()) {
          throw new _error.MotionError(_error.ERROR_CODE.ALREADY_MOTION_APP);
        }
        yield (0, _fs.mkdir)(this.config.rootDirectory);
        yield (0, _fs.copy)(_path2.default.normalize(_path2.default.join(__dirname, '..', 'template')), this.config.rootDirectory);
        this.state.write();
      });

      function init() {
        return ref.apply(this, arguments);
      }

      return init;
    }()
  }, {
    key: 'onDidError',
    value: function onDidError(callback) {
      return this.emitter.on('did-error', callback);
    }
  }, {
    key: 'dispose',
    value: function dispose() {
      this.subscriptions.dispose();
    }
  }], [{
    key: 'create',
    value: function () {
      var ref = _asyncToGenerator(function* (config) {
        if (yield (0, _fs.exists)(config.rootDirectory)) {
          config.rootDirectory = yield (0, _fs.realpath)(config.rootDirectory);
        }
        (0, _helpers.fillConfig)(config);
        var state = yield _state2.default.create(_path2.default.join(config.dataDirectory, 'state.json'), _path2.default.join(config.dataDirectory, 'config.json'));
        return new Motion(state, config);
      });

      function create(_x5) {
        return ref.apply(this, arguments);
      }

      return create;
    }()
  }]);

  return Motion;
}();

module.exports = Motion;
//# sourceMappingURL=index.js.map